version 11.0
#delimit ;
log using "C:\matt\publications\jop2\webpage\interaction3.log", replace;
set more off;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      interaction3.do                                 *;
*       Date:           1/8/2013                                        *;
*       Author:         MG                                              *;
*       Purpose:        Do-file to produce a marginal effect plot for   *;
*                       X when the interaction model is:                *;
*                       Pr(Y=1) = Phi(b0 + b1X + b2Z + b3XZ)            *;
*       Input File:     interaction3.dta                                *;
*       Output File:    interaction3.log                                *;
*       Data Output:    None	                                        *;
*       Previous file:  None                                            *;
*       Machine:        laptop                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\matt\publications\jop2\webpage\interaction3.dta", clear;

*     ****************************************************************  *;
*                           Estimate Probit Model                       *;
*     ****************************************************************  *;           
             
xtprobit pec polarization threshold polarization_threshold 
        seatshare seatshare_2 incompatibility  asymmetry asym_seat, re i (ident);
        
*     ****************************************************************  *;
*       Take 10,000 draws from the estimated coefficient vector and     *;
*       variance-covariance matrix.                                     *;
*     ****************************************************************  *;

preserve;

set seed 339487731;

drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;

*     ****************************************************************  *;
*       To calculate the desired quantities of interest we need to set  *;
*       up a loop.  This is what we do here.                            *;
*     ****************************************************************  *;
*       First, specify what you quantities should be saved and what     *;
*       these quantities should be called.                              *;
*     ****************************************************************  *;

postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
            using "C:\matt\publications\jop2\webpage\sim.dta", replace;
            
noisily display "start";
            
*     ****************************************************************  *;
*       Start loop.  Let `a' be the modifying variable Z and let this   *;
*       run from min to max in the desired increments.                  *;
*     ****************************************************************  *; 

local a=0 ;
while `a' <= 35 { ;

{;

scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_seatshare=31.37;
scalar h_seatshare_2=(h_seatshare*h_seatshare);
scalar h_incompatibility= 24.41;
scalar h_asymmetry=.545;
scalar h_constant=1;          

    generate x_betahat0  = SN_b1*h_polarization 
                            + SN_b2*`a'   
                            + SN_b3*h_polarization*`a' 
                            + SN_b4*h_seatshare 
                            + SN_b5*h_seatshare_2
                            + SN_b6*h_incompatibility
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*h_seatshare
                            + SN_b9*h_constant;
                            
    generate x_betahat1  = SN_b1*(h_polarization+1) 
                            + SN_b2*`a'   
                            + SN_b3*(h_polarization+1)*(`a') 
                            + SN_b4*h_seatshare 
                            + SN_b5*h_seatshare_2
                            + SN_b6*h_incompatibility
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*h_seatshare
                            + SN_b9*h_constant;  
    
    gen prob0 =normal(x_betahat0);
    gen prob1=normal(x_betahat1);
    gen diff=prob1-prob0;
    
    egen probhat0 =mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi;  

    _pctile prob0, p(2.5,97.5) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  
   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi');
   
    };      
    
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat;
    
    local a=`a'+ 1;
    
    display "." _c;
    
} ;

display "";

postclose mypost;

*     ****************************************************************  *;                                  
*       Call on posted quantities of interest                           *;
*     ****************************************************************  *;

restore;

merge using "C:\matt\publications\jop2\webpage\sim.dta";

gen yline=0;

gen MV = _n-1;

replace  MV=. if _n>36;

graph twoway hist threshold, percent color(gs14) yaxis(2)
        ||  line diff_hat MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||  line diff_lo MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line diff_hi MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line yline MV,  clwidth(thin) clcolor(black) clpattern(solid)
        ||  ,   
            xlabel(0 5 10 15 20 25 30 35, nogrid labsize(2)) 
            ylabel(0 .001 .003 .005 .007, axis(1) nogrid labsize(2))
            ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
            yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
            yline(0, lcolor(black))
            yline(.001 .003 .005 .007, lcolor(white))
            xtitle("Effective Threshold", size(2.5))
            ytitle("Marginal Effect of Polarization", size(2.5))
            ytitle("Percent of Observations" , axis(2) size(2.5))
            xsca(titlegap(4)) ysca(titlegap(4)) ysca(axis(2) titlegap(4))
            scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));
            
log close;

